@@ -1,10 +1,10 @@
 from youtubesearchpython.__future__.search import Search, VideosSearch, ChannelsSearch, PlaylistsSearch, CustomSearch
-from youtubesearchpython.__future__.extras import Video, Suggestions
+from youtubesearchpython.__future__.extras import Video, Playlist, Suggestions
 from youtubesearchpython.__future__.streamurlfetcher import StreamURLFetcher
 from youtubesearchpython.__future__.internal.constants import *
 
 
 __title__        = 'youtube-search-python'
-__version__      = '1.4.0'
+__version__      = '1.4.1'
 __author__       = 'alexmercerind'
 __license__      = 'MIT'
